parserFwk.pyparsing.ParseBaseException

Package parserFwk :: Module pyparsing :: Class ParseBaseException |
[frames | no frames]

## Type ParseBaseException

       object --+
                |
    BaseException --+
                    |
            Exception --+
                        |
                       ParseBaseException

Known Subclasses:
  `ParseException`, `ParseFatalException`

base exception class for all parsing runtime exceptions

Method Summary
| `__init__(self, pstr, loc, msg, elem)`
| ``__getattr__`(self, aname)` supported attributes by name are:
| `__repr__(self)`
| `__str__(self)`
| ``markInputline`(self, markerString)` Extracts the exception line from the input string, and marks the location of the exception with a special symbol.
Inherited from `Exception`: `__new__` Inherited from `BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__setattr__`, `__setstate__` Inherited from `object`: `__hash__`, `__reduce_ex__`

Class Variable Summary
`tuple` | `__slots__` = `('loc', 'msg', 'pstr', 'parserElement')`
`member_descriptor` | `loc` = `<member 'loc' of 'ParseBaseException' objects>`
`member_descriptor` | `msg` = `<member 'msg' of 'ParseBaseException' objects>`
`member_descriptor` | `parserElement` = `<member 'parserElement' of 'ParseBaseExc...`
`member_descriptor` | `pstr` = `<member 'pstr' of 'ParseBaseException' objects>`
Inherited from `BaseException`: `args`, `message`

Method Details

### __getattr__(self, aname) (Qualification operator) supported attributes by name are: lineno - returns the line number of the exception text col - returns the column number of the exception text line - returns the line containing the exception text

### markInputline(self, markerString='>!<') Extracts the exception line from the input string, and marks the location of the exception with a special symbol.

Class Variable Details

    ### __slots__ Type: `tuple` Value:
        ('loc', 'msg', 'pstr', 'parserElement')

    ### loc Type: `member_descriptor` Value:
        <member 'loc' of 'ParseBaseException' objects>

    ### msg Type: `member_descriptor` Value:
        <member 'msg' of 'ParseBaseException' objects>

    ### parserElement Type: `member_descriptor` Value:
        <member 'parserElement' of 'ParseBaseException' objects>

    ### pstr Type: `member_descriptor` Value:
        <member 'pstr' of 'ParseBaseException' objects>

Generated by Epydoc 2.1 on Sun Oct 07 01:31:52 2007 | http://epydoc.sf.net